##########################################################################
# VaRank 1.1.1                                                           #
#                                                                        #
# VaRank: a simple and powerful tool for ranking genetic variants        #
#                                                                        #
# Copyright (C) 2014 Veronique Geoffroy (veronique.geoffroy@inserm.fr)   # 
#                    Jean Muller (jeanmuller@unistra.fr)                 # 
#                                                                        #
# Please cite the following article:                                     #
#    XXX                                                                 #
#                                                                        #
# This is part of VaRank source code.                                    #
#                                                                        #
# This program is free software; you can redistribute it and/or          #
# modify it under the terms of the GNU General Public License            # 
# as published by the Free Software Foundation; either version 3         # 
# of the License, or (at your option) any later version.                 #
#                                                                        #
# This program is distributed in the hope that it will be useful,        # 
# but WITHOUT ANY WARRANTY; without even the implied warranty of         #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          #
# GNU General Public License for more details.                           #
#                                                                        #
# You should have received a copy of the GNU General Public License      #
# along with this program; If not, see <http://www.gnu.org/licenses/>.   #
##########################################################################

proc showHelp {} {

    global g_VaRank
    
    VaRank_Version

    set HelpText "VaRank $g_VaRank(Version)\n\n"

    append HelpText "VaRank is a program for genetic Variant Ranking from NGS data\n\n"

    append HelpText "Copyright (C) 2014 GEOFFROY Veronique, MULLER Jean\n\n"

    append HelpText "Please feel free to contact us for any suggestions or bug reports\n"
    append HelpText "email: veronique.geoffroy@inserm.fr; jeanmuller@unistra.fr\n\n"

    append HelpText "COMMAND LINE USAGE:\n"
    append HelpText "-------------------\n"
    append HelpText "$g_VaRank(sourcesDir)/bin/VaRank -vcfdir 'Path of your study directory containing your vcf input file' >& VaRank.log &\n\n"
   
    append HelpText "OPTIONS:\n"
    append HelpText "--------\n"
    append HelpText "-help			More information on the arguments\n\n"

    append HelpText "-vcfDir			Path of your study directory containing your vcf input file\n\n"

    append HelpText "-vcfInfo		To extract the info column from the .vcf file and insert the data in the outputfile (last columns).\n"
    append HelpText "                     	Range values: yes or no (default)\n\n"

    append HelpText "-rsfromvcf		To extract the rsID and validation status from the .vcf file and insert this in the outputfile.\n"
    append HelpText "                     	Range values: yes or no (default)\n\n"

    append HelpText "-nowebsearch		To allow or not the access to the web for downloading the fasta sequences for missed proteins in UniProt and/or RefSeq (only suitable when used with PolyPhen-2). It is to notice that the search can be very time consuming since getting sequences one by one.\n"
    append HelpText "                     	Range values: yes (default) or no\n\n"

    append HelpText "-Homstatus    	     	To force the determination of the homozygous or heterozygous state of one variation. If set to yes it will use the Homcutoff value to decide.\n"
    append HelpText "                     	Range values: yes or no (default)\n\n"

    append HelpText "-Homcutoff    	     	To determine the homozygous or heterozygous state of one variation. If set to some value it will force to reconsider the data provided.\n"
    append HelpText "                     	Range values: \[0,100\] default: 80 (active only if Homstatus=yes or when no status is given)\n\n"

    append HelpText "-MEScutoff    	     	MaxEntScan cutoff, to determine the impact of the variant on splicing. Expressed as the % difference between the variant and the WT score.\n"
    append HelpText "                     	Range values: \[-100,0\], default: -15\n\n"

    append HelpText "-SSFcutoff       	Splice Site Finder cutoff, to determine the impact of the variant on splicing. Expressed as the % difference between the variant and the WT score.\n"
    append HelpText "                    	Range values: \[-100,0\], default: -5\n\n"

    append HelpText "-NNScutoff       	NNSplice cutoff, to determine the impact of the variant on splicing. Expressed as the % difference between the variant and the WT score.\n"
    append HelpText "                     	Range values: \[-100,0\], default: -10\n\n"

    append HelpText "-phastConsCutoff     	To determine when a genomic position is conserved or not. Above the cutoff is considered as conserved.\n"
     append HelpText "                    	Range values: \[0,1\], default: 0.95\n\n"

    append HelpText "-readFilter          	Minimum number of reads for the variants\n"
    append HelpText "                     	Range values: \[0,-\], default: 10\n\n"

    append HelpText "-depthFilter         	Minimum depth for the variants\n"
    append HelpText "                     	Range values: \[0,-\], default: 10\n\n"

    append HelpText "-readPercentFilter   	Minimum percent of variant reads for considering a variant\n"
    append HelpText "                     	Range values: \[0,100\], default: 10\n\n"

    append HelpText "-freqFilter          	Filtering variants based on their MAF in the SNV databases (dbsnp and EVS)\n"
    append HelpText "                     	Range values: \[0.0,1.0\], default: 0.01\n\n"

    append HelpText "-rsFilter            	Filtering variants on the SNP informations\n"
    append HelpText "                     	Values: removeNonPathoRS (remove variants without \"probable-pathogenic\" or \"pathogenic\" annotation, see clinical significance field in dbSNP website. Filtering only for variants with at least 2 validations.)\n"
    append HelpText "                             none = keep all variants, no filtering on rsID\n"
    append HelpText "                     	default: removeNonPathoRS\n\n"

    append HelpText "-extann              	Tab separated file containing annotation to add to the final output files. Restrictions for the format are: 1st line is a header, 1st column is the gene name\n"
    append HelpText "                     	Typical use would be a gene file containing specific annotations such as transmission mode, disease, expression...\n\n"

    append HelpText "-metrics             	Changing numerical values from frequencies to us or fr metrics (ex: 0.2 or 0,2)\n"
    append HelpText "                     	Range values: us (default) or fr\n\n"

    append HelpText "-DB          		Changes the directory where the UniProt and Refseq files are stored (optional, only use if PPH2 is installed)\n"
     append HelpText "                    	Ex: $g_VaRank(sourcesDir)/Databases (default)\n\n"

    append HelpText "-uniprot             	Name of the UniProt sequence file (optional, only use if PPH2 is installed)\n"
    append HelpText "                     	Ex: HUMAN.fasta.gz (default)\n\n"

    append HelpText "-refseq              	Name of the RefSeq sequence file (optional, only use if PPH2 is installed)\n"
     append HelpText "                    	Ex: human.protein.faa.gz (default)\n\n"

    append HelpText "-hgmdUser            	HGMD User login (optional, only use if you have an HGMD license)\n\n"
   
    append HelpText "-hgmdPasswd          	HGMD User password (optional, only use if you have an HGMD license)\n\n"


    append HelpText "The following options are provided to allow the user to modify the VaRank score corresponding to each category defined by the program:\n"
    append HelpText "-S_Known     		Known mutation as annotated by HGMD and/or dbSNP (rsClinicalSignificance=\"pathogenic/probable-pathogenic\").\n"
    append HelpText "		     	Default: 110\n\n"

    append HelpText "-S_Nonsense          	A single-base substitution in DNA resulting in a STOP codon (TGA, TAA or TAG).\n"
    append HelpText "		     	default: 100\n\n"

    append HelpText "-S_Fs            	Exonic insertion/deletion of a non-multiple of 3bp resulting often in a premature stop in the reading frame of the gene.\n"
    append HelpText "		  	default: 100\n\n"

    append HelpText "-S_EssentialSplice  	Mutation in one of the canonical splice sites resulting in a significant effect on splicing (at least 2 out of the 3 programs indicate a relative variation in their score compared to the wild type sequence)\n"
    append HelpText "			default: 90\n\n"

    append HelpText "-S_StartLoss         	Mutation leading to the loss of the initiation codon (Met).\n"
    append HelpText "		     	default: 80\n\n"

    append HelpText "-S_StopLoss       	Mutation leading to the loss of the STOP codon.\n"
    append HelpText "			default: 80\n\n"

    append HelpText "-S_CloseSplice       Mutation outside of the canonical splice sites (donor site is -3 to +6', acceptor site -12 to +2) resulting in a significant effect on splicing (at least 2 out of the 3 programs indicate a relative variation in their score compared to the wild type sequence).\n"
    append HelpText "		     	default: 70\n\n"

    append HelpText "-S_Missense          	A single-base substitution in DNA not resulting in a change in the amino acid.\n"
    append HelpText "		     	default: 50\n\n"

    append HelpText "-S_Inframe           	Exonic insertion/deletion of a multiple of 3bp.\n"
    append HelpText "		     	default: 40\n\n"

    append HelpText "-S_DeepSplice        	Intronic mutation resulting in a significant effect on splicing (at least 2 out of the 3 programs indicate a relative variation in their score compared to the wild type sequence).\n"
    append HelpText "		     	default: 25\n\n"

    append HelpText "-S_Synonymous        	A single-base substitution in DNA not resulting in a change in the amino acid.\n"
    append HelpText "		     	default: 10\n\n"

    append HelpText "-B_phastCons		Each variant score is adjusted if a conservation at the genomic level is observed (PhastCons cutoff >0.95)\n"
    append HelpText "			default: 5\n\n"

    append HelpText "-B_SIFT			Missenses scores are adjusted for each SIFT deleterious prediction\n"
    append HelpText "			default: 5\n\n"

    append HelpText "-B_PPH2			Missenses scores are adjusted for each PPH2 deleterious prediction\n"
    append HelpText "			default: 5\n\n"


    puts "$HelpText"

    return
}


